@@ -15,8 +15,6 @@
 # limitations under the License.
 # ******************************************************************************
 
-import os
-
 from tensorflow.keras.layers import Input, Flatten
 from tensorflow.keras import Model
 from tensorflow.keras.utils import get_file
@@ -31,7 +29,6 @@ BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/vgg/'
 
 def vgg_cifar10(input_shape=(32, 32, 3),
                 classes=10,
-                weights=None,
                 weight_quantization=0,
                 activ_quantization=0,
                 input_weight_quantization=None):
@@ -44,8 +41,6 @@ def vgg_cifar10(input_shape=(32, 32, 3),
     Args:
         input_shape (tuple): input shape tuple of the model
         classes (int): number of classes to classify images into
-        weights (str): one of `None` (random initialization) or the path to the
-            weights file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -157,10 +152,6 @@ def vgg_cifar10(input_shape=(32, 32, 3),
 
     model = Model(img_input, x, name='vgg_cifar10')
 
-    # Load weights
-    if weights is not None:
-        model.load_weights(weights, by_name=True)
-
     if ((weight_quantization != 0) or (activ_quantization != 0) or
         (input_weight_quantization != 0)):
         return quantize(model, weight_quantization, activ_quantization,
@@ -178,8 +169,10 @@ def vgg_cifar10_pretrained():
         tf.keras.Model: a Keras Model instance.
 
     """
-    model_name = 'vgg_cifar10_wq2_aq2.hdf5'
+    model_name = 'vgg_cifar10_iq2_wq2_aq2.h5'
+    file_hash = '4F7CAE882447C296B1EFFF2F63242E9700E1439C9295A75C6164D403E887F0ED'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
