@@ -30,6 +30,9 @@ from .utk_face.model_vgg import vgg_utk_face
 from .kws.model_ds_cnn import ds_cnn_kws
 from .imagenet.model_mobilenet import mobilenet_imagenet
 from .imagenet.model_mobilenet_edge import mobilenet_edge_imagenet
+from .detection.model_yolo import yolo_base
+from .dvs.model_convtiny_handy import convtiny_dvs_handy
+from .dvs.model_convtiny_gesture import convtiny_dvs_gesture
 
 
 def main():
@@ -48,6 +51,22 @@ def main():
         help="A Depthwise Separable CIFAR10 model inspired by MobileNet")
     csp.add_parser("vgg_cifar10", help="A VGG-like CIFAR10 model")
     csp.add_parser("vgg_utk_face", help="A VGG-like UTKFace model")
+    csp.add_parser("convtiny_dvs_handy", help="A Convtiny DVS handy model")
+    dvsh_parser = csp.add_parser("convtiny_dvs_handy",
+                                 help="A Convtiny DVS model for akida")
+    dvsh_parser.add_argument("-c",
+                             "--classes",
+                             type=int,
+                             default=9,
+                             help="The number of classes")
+    csp.add_parser("convtiny_dvs_gesture", help="A Convtiny DVS gesture model")
+    dvsg_parser = csp.add_parser("convtiny_dvs_gesture",
+                                 help="A Convtiny DVS model for akida")
+    dvsg_parser.add_argument("-c",
+                             "--classes",
+                             type=int,
+                             default=9,
+                             help="The number of classes")
     csp.add_parser(
         "ds_cnn_kws",
          help="A Depthwise Separable MobileNet-like model for the Keyword" \
@@ -85,6 +104,28 @@ def main():
                             type=int,
                             default=1000,
                             help="The number of edge learning classes")
+    yl_parser = csp.add_parser("yolo_base", help="A YOLOv2 model for detection")
+    yl_parser.add_argument("-c",
+                           "--classes",
+                           type=int,
+                           default=1,
+                           help="The number of classes")
+    yl_parser.add_argument("-na",
+                           "--number_anchors",
+                           type=int,
+                           default=5,
+                           help="The number of anchor boxes")
+    yl_parser.add_argument("-a",
+                           "--alpha",
+                           type=float,
+                           default=0.5,
+                           help="The width of the model")
+    yl_parser.add_argument("-bw",
+                           "--base_weights",
+                           type=str,
+                           default=None,
+                           help="The base MobileNet weights to use for \
+                            transfer learning.")
     args = parser.parse_args()
     if args.action == "create":
         model_path = args.save_model
@@ -95,6 +136,10 @@ def main():
             model = vgg_cifar10()
         elif args.model == "vgg_utk_face":
             model = vgg_utk_face()
+        elif args.model == "convtiny_dvs_handy":
+            model = convtiny_dvs_handy(classes=args.classes)
+        elif args.model == "convtiny_dvs_gesture":
+            model = convtiny_dvs_gesture(classes=args.classes)
         elif args.model == "ds_cnn_kws":
             model = ds_cnn_kws()
         elif args.model == "mobilenet_imagenet":
@@ -109,6 +154,12 @@ def main():
                                             classes=args.classes)
             if model_path is None:
                 model_path = f"{model.name}.h5"
+        elif args.model == "yolo_base":
+            model = yolo_base(classes=args.classes,
+                              nb_box=args.number_anchors,
+                              alpha=args.alpha)
+            if args.base_weights is not None:
+                model.load_weights(args.base_weights, by_name=True)
         # No need for default behaviour as the command-line parser only accepts
         # valid model types
         if model_path is None:
