@@ -32,7 +32,6 @@ from cnn2snn import load_quantized_model, quantize
 def yolo_base(input_shape=(224, 224, 3),
               classes=1,
               nb_box=5,
-              grid_size=(7, 7),
               alpha=1.0,
               dropout=1e-3,
               weight_quantization=0,
@@ -44,7 +43,6 @@ def yolo_base(input_shape=(224, 224, 3),
         input_shape (tuple): input shape tuple
         classes (int): number of classes to classify images into
         nb_box (int): number of anchors boxes to use
-        grid_size (tuple): YOLO grid size tuple
         alpha (float): controls the width of the model
         dropout (float): dropout rate
         weight_quantization (int): sets all weights in the model to have
@@ -125,6 +123,8 @@ def yolo_base(input_shape=(224, 224, 3),
     detection_weights = layer.get_weights()
 
     mu, sigma = 0, 0.1
+
+    grid_size = model.output_shape[1:3]
     grid_area = grid_size[0] * grid_size[1]
 
     dw_kernel = np.random.normal(mu, sigma,
