@@ -25,22 +25,21 @@ from tensorflow.keras.layers import Reshape
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras.callbacks import EarlyStopping
 
-from akida_models.detection.map_evaluation import MapEvaluation
-
 from cnn2snn import load_quantized_model
 
 from .yolo_loss import YoloLoss
+from .map_evaluation import MapEvaluation
 from .batch_generator import BatchGenerator
 
 
-def compile_model(model_path, anchors, grid_size, tune, freeze, num_classes,
-                  batch_size):
+def compile_model(model_path, anchors, tune, freeze, num_classes, batch_size):
     nb_box = len(anchors)
 
     # Load the source model
     base_model = load_quantized_model(model_path)
 
     # Create a final reshape layer for loss computation
+    grid_size = base_model.output_shape[1:3]
     output = Reshape((grid_size[1], grid_size[0], nb_box, 4 + 1 + num_classes),
                      name="YOLO_output")(base_model.output)
 
@@ -71,16 +70,16 @@ def compile_model(model_path, anchors, grid_size, tune, freeze, num_classes,
         for layer in model.layers[-11:]:  # unfreeze top layers for YOLO
             layer.trainable = True
 
-    return model
+    return model, grid_size
 
 
-def train(model_path, train_data, valid_data, anchors, grid_size, labels,
-          obj_threshold, nms_threshold, epochs, tune, freeze, batch_size):
+def train(model_path, train_data, valid_data, anchors, labels, obj_threshold,
+          nms_threshold, epochs, tune, freeze, batch_size):
     TRAIN_TIMES = 10
 
     # Compile model
-    model = compile_model(model_path, anchors, grid_size, tune, freeze,
-                          len(labels), batch_size)
+    model, grid_size = compile_model(model_path, anchors, tune, freeze,
+                                     len(labels), batch_size)
 
     # Build batch generators
     input_shape = model.input.shape[1:]
@@ -129,12 +128,12 @@ def train(model_path, train_data, valid_data, anchors, grid_size, labels,
     return model
 
 
-def evaluate(model_path, valid_data, anchors, grid_size, labels, obj_threshold,
+def evaluate(model_path, valid_data, anchors, labels, obj_threshold,
              nms_threshold, batch_size):
 
     # Compile model
-    model = compile_model(model_path, anchors, grid_size, True, False,
-                          len(labels), batch_size)
+    model, _ = compile_model(model_path, anchors, True, False, len(labels),
+                             batch_size)
 
     # Create the mAP evaluator
     map_evaluator = MapEvaluation(model,
@@ -219,16 +218,16 @@ def main():
                          "pickle file path produced by the preprocessing step")
 
     with open(data_path, 'rb') as handle:
-        train_data, valid_data, grid_size, labels = pickle.load(handle)
+        train_data, valid_data, labels = pickle.load(handle)
 
     with open(anchors_path, 'rb') as handle:
         anchors = pickle.load(handle)
 
     if args.action != 'eval':
         # Train/tune the model
-        model = train(args.model, train_data, valid_data, anchors, grid_size,
-                      labels, args.obj_thresh, args.nms_thresh, epochs, tune,
-                      freeze, args.batch_size)
+        model = train(args.model, train_data, valid_data, anchors, labels,
+                      args.obj_thresh, args.nms_thresh, epochs, tune, freeze,
+                      args.batch_size)
         if args.savemodel:
             # Remove the last reshape layer introduced for training
             model = Model(model.input, model.layers[-2].output)
@@ -237,8 +236,8 @@ def main():
             print(f"Trained model saved as {args.savemodel}")
     else:
         # Evaluate the model
-        evaluate(args.model, valid_data, anchors, grid_size, labels,
-                 args.obj_thresh, args.nms_thresh, args.batch_size)
+        evaluate(args.model, valid_data, anchors, labels, args.obj_thresh,
+                 args.nms_thresh, args.batch_size)
 
 
 if __name__ == "__main__":
