@@ -255,6 +255,44 @@ def parse_record(raw_record, im_size, is_training, dtype):
     return image, label
 
 
+def get_val_dataset(data_dir, batch_size, im_size, preprocessing_fn, dtype):
+    """Input function which provides validation batches
+
+  Args:
+    data_dir: The directory containing the input data.
+    batch_size: The number of samples per batch.
+    im_size: The size of output images
+    preprocessing_fn: Function to use for preprocessing images.
+    dtype: Data type to use for images/features
+
+  Returns:
+    A dataset that can be used for iteration.
+  """
+    # Read validation files
+    filenames = get_filenames(False, data_dir)
+    dataset = tf.data.Dataset.from_tensor_slices(filenames)
+    # Convert to individual records.
+    # cycle_length = 10 means that up to 10 files will be read and deserialized in
+    # parallel. You may want to increase this number if you have a large number of
+    # CPU cores.
+    dataset = dataset.interleave(
+        tf.data.TFRecordDataset,
+        cycle_length=tf.data.experimental.AUTOTUNE,
+        num_parallel_calls=tf.data.experimental.AUTOTUNE)
+
+    return process_record_dataset(dataset=dataset,
+                                  is_training=False,
+                                  batch_size=batch_size,
+                                  im_size=im_size,
+                                  shuffle_buffer=_SHUFFLE_BUFFER,
+                                  parse_record_fn=preprocessing_fn,
+                                  num_epochs=1,
+                                  dtype=dtype,
+                                  datasets_num_private_threads=None,
+                                  drop_remainder=False,
+                                  tf_data_experimental_slack=False)
+
+
 def input_fn(is_training,
              data_dir,
              batch_size,
