@@ -20,7 +20,7 @@ from tensorflow.keras.layers import Input, Reshape, Activation, Flatten
 from tensorflow.keras.utils import get_file
 
 # CNN2SNN imports
-from cnn2snn import load_quantized_model, quantize
+from cnn2snn import load_quantized_model, quantize, quantize_layer
 
 from ..layer_blocks import conv_block, separable_conv_block, dense_block
 
@@ -171,10 +171,8 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
 
     # Change the last layer activation bitwidth
     if last_layer_activ_quantization != activ_quantization:
-        layer_names = [layer.name for layer in model.layers]
-        layer_idx = layer_names.index('separable_6')
-        last_act_layer = model.layers[layer_idx + 1]
-        last_act_layer.bitwidth = last_layer_activ_quantization
+        model = quantize_layer(model, 'separable_6_relu',
+                               last_layer_activ_quantization)
 
     return model
 
