@@ -93,10 +93,6 @@ def conv_block(inputs,
     if 'activation' in kwargs.keys() and kwargs['activation']:
         raise ValueError(
             "Keyword argument 'activation' in conv_block must be None.")
-    if 'strides' in kwargs.keys():
-        if kwargs['strides'] != 1 and kwargs['strides'] != (1, 1):
-            print("WARNING: Keyword argument 'strides' is not supported in "
-                  "conv_block except for the first layer.")
     if 'dilation_rate' in kwargs.keys():
         if kwargs['dilation_rate'] != 1 and kwargs['dilation_rate'] != (1, 1):
             raise ValueError("Keyword argument 'dilation_rate' is not "
@@ -155,10 +151,6 @@ def separable_conv_block(inputs,
     if 'activation' in kwargs.keys() and kwargs['activation']:
         raise ValueError("Keyword argument 'activation' in separable_conv_block"
                          " must be None.")
-    if 'strides' in kwargs.keys():
-        if kwargs['strides'] != 1 and kwargs['strides'] != (1, 1):
-            raise ValueError("Keyword argument 'strides' is not supported in "
-                             "separable_conv_block.")
     if 'dilation_rate' in kwargs.keys():
         if kwargs['dilation_rate'] != 1 and kwargs['dilation_rate'] != (1, 1):
             raise ValueError("Keyword argument 'dilation_rate' is not "
