@@ -20,14 +20,10 @@ import tensorflow as tf
 
 from tensorflow.keras.layers import Input, Activation, Reshape, Flatten
 
-from ..quantization_blocks import dense_block
+from ..layer_blocks import dense_block
 
 
-def create_tse(numerical_columns,
-               categorical_columns,
-               units,
-               input_weight_quantization=0,
-               activ_quantization=0):
+def create_tse(numerical_columns, categorical_columns, units):
     """
     Create a Trainable Spike Encoder (TSE) network.
 
@@ -93,8 +89,7 @@ def create_tse(numerical_columns,
     x = dense_block(feature_layer_outputs,
                     units=units,
                     name='dense_to_spike',
-                    weight_quantization=input_weight_quantization,
-                    activ_quantization=activ_quantization,
+                    add_activation=True,
                     add_batchnorm=True)
     x = Reshape(target_shape=(1, 1, units), name='final_embedding_reshape')(x)
 
@@ -140,14 +135,12 @@ def create_mlp(inputs,
         x = dense_block(x,
                         units=units_list[i],
                         name='dense' + str(i + 1),
-                        weight_quantization=weight_quantization,
-                        activ_quantization=activ_quantization,
+                        add_activation=True,
                         add_batchnorm=True)
     x = dense_block(x,
                     units=n_classes,
                     name='last_dense',
-                    weight_quantization=weight_quantization,
-                    activ_quantization=None,
+                    add_activation=False,
                     use_bias=False)
     x = Activation('softmax', name='activation')(x)
     return x
