@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # ******************************************************************************
-# Copyright 2019 Brainchip Holdings Ltd.
+# Copyright 2020 Brainchip Holdings Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,8 +15,6 @@
 # limitations under the License.
 # ******************************************************************************
 
-import os
-
 from tensorflow.keras import Model
 from tensorflow.keras.layers import Dropout, Flatten, Input
 from tensorflow.keras.utils import get_file
@@ -30,7 +28,6 @@ BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/vgg/'
 
 
 def vgg_utk_face(input_shape=(32, 32, 3),
-                 weights=None,
                  weight_quantization=0,
                  activ_quantization=0,
                  input_weight_quantization=None):
@@ -39,8 +36,6 @@ def vgg_utk_face(input_shape=(32, 32, 3),
 
     Args:
         input_shape (tuple): input shape tuple of the model
-        weights (str): one of `None` (random initialization), 'utkface' for
-            pretrained weights or the path to the weights file to be loaded.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -134,10 +129,6 @@ def vgg_utk_face(input_shape=(32, 32, 3),
 
     model = Model(img_input, x, name='vgg_utk_face')
 
-    # Load weights
-    if weights is not None:
-        model.load_weights(weights, by_name=True)
-
     if ((weight_quantization != 0) or (activ_quantization != 0) or
         (input_weight_quantization != 0)):
         return quantize(model, weight_quantization, activ_quantization,
@@ -156,7 +147,9 @@ def vgg_utk_face_pretrained():
 
     """
     model_name = 'vgg_utk_face_iq8_wq2_aq2.h5'
+    file_hash = 'C5F7C722C19DD1F2F9743ACD8D315B0EF51ADB1F2DD42138B1E34C5F81782B96'
     model_path = get_file(fname=model_name,
                           origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
\ No newline at end of file
